@@ -1,14 +1,28 @@
+from __future__ import annotations
+
 import logging
 import math
-from typing import Any
+from typing import Any, Literal
 
 from lightning.pytorch import LightningModule, Trainer
 from lightning.pytorch.callbacks import Callback
-from typing_extensions import override
+from typing_extensions import final, override
+
+from .base import CallbackConfigBase, callback_registry
 
 log = logging.getLogger(__name__)
 
 
+@final
+@callback_registry.register
+class LogEpochCallbackConfig(CallbackConfigBase):
+    name: Literal["log_epoch"] = "log_epoch"
+
+    @override
+    def create_callbacks(self, trainer_config):
+        yield LogEpochCallback()
+
+
 class LogEpochCallback(Callback):
     def __init__(self, metric_name: str = "computed_epoch"):
         super().__init__()
