@@ -1,13 +1,16 @@
+from __future__ import annotations
+
 from .mlp import MLP as MLP
+from .mlp import MLPConfig as MLPConfig
 from .mlp import ResidualSequential as ResidualSequential
 from .module_dict import TypedModuleDict as TypedModuleDict
 from .module_list import TypedModuleList as TypedModuleList
-from .nonlinearity import BaseNonlinearityConfig as BaseNonlinearityConfig
 from .nonlinearity import ELUNonlinearityConfig as ELUNonlinearityConfig
 from .nonlinearity import GELUNonlinearityConfig as GELUNonlinearityConfig
 from .nonlinearity import LeakyReLUNonlinearityConfig as LeakyReLUNonlinearityConfig
 from .nonlinearity import MishNonlinearityConfig as MishNonlinearityConfig
 from .nonlinearity import NonlinearityConfig as NonlinearityConfig
+from .nonlinearity import NonlinearityConfigBase as NonlinearityConfigBase
 from .nonlinearity import PReLUConfig as PReLUConfig
 from .nonlinearity import ReLUNonlinearityConfig as ReLUNonlinearityConfig
 from .nonlinearity import SigmoidNonlinearityConfig as SigmoidNonlinearityConfig
@@ -17,3 +20,5 @@ from .nonlinearity import SoftplusNonlinearityConfig as SoftplusNonlinearityConf
 from .nonlinearity import SoftsignNonlinearityConfig as SoftsignNonlinearityConfig
 from .nonlinearity import SwishNonlinearityConfig as SwishNonlinearityConfig
 from .nonlinearity import TanhNonlinearityConfig as TanhNonlinearityConfig
+from .rng import RNGConfig as RNGConfig
+from .rng import rng_context as rng_context
