@@ -1,8 +1,10 @@
-from logging import getLogger
+from __future__ import annotations
+
+import logging
 
 import lightning.fabric.utilities.seed as LS
 
-log = getLogger(__name__)
+log = logging.getLogger(__name__)
 
 
 def seed_everything(seed: int | None, *, workers: bool = False):
