@@ -1,8 +1,10 @@
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 
 from typing_extensions import TypeVar
 
-TBase = TypeVar("TBase")
+TBase = TypeVar("TBase", infer_variance=True)
 
 
 def mixin_base_type(base_class: type[TBase]) -> type[TBase]:
